@@ -23,6 +23,9 @@
 #include "KGpgOrphanNode.h"
 #include "kgpgsettings.h"
 
+#include <QString>
+#include <QStringList>
+
 KGpgRootNode::KGpgRootNode(KGpgItemModel *model)
 	: KGpgExpandableNode(NULL),
 	m_groups(0),
@@ -50,19 +53,18 @@ KGpgRootNode::getType() const
 void
 KGpgRootNode::addGroups(const QStringList &groups)
 {
-	foreach (const QString &groupName, groups)
-		new KGpgGroupNode(this, groupName);
+	foreach (const QString &group, groups) {
+		QStringList members = group.split(QLatin1Char(' '));
+		const QString groupName = members.takeFirst();
+		new KGpgGroupNode(this, groupName, members);
+	}
 }
 
 void
 KGpgRootNode::addKeys(const QStringList &ids)
 {
-	KgpgInterface *interface = new KgpgInterface();
-
-	KgpgCore::KgpgKeyList publiclist = interface->readPublicKeys(true, ids);
-	KgpgCore::KgpgKeyList secretlist = interface->readSecretKeys();
-
-	delete interface;
+	KgpgCore::KgpgKeyList publiclist = KgpgInterface::readPublicKeys(ids);
+	KgpgCore::KgpgKeyList secretlist = KgpgInterface::readSecretKeys();
 
 	QStringList issec = secretlist;
 
@@ -95,12 +97,8 @@ KGpgRootNode::refreshKeys(KGpgKeyNode::List nodes)
 	foreach (const KGpgNode *nd, nodes)
 		ids << nd->getId();
 
-	KgpgInterface *interface = new KgpgInterface();
-
-	KgpgCore::KgpgKeyList publiclist = interface->readPublicKeys(true, ids);
-	QStringList issec = interface->readSecretKeys(ids);
-
-	delete interface;
+	KgpgCore::KgpgKeyList publiclist = KgpgInterface::readPublicKeys(ids);
+	QStringList issec = KgpgInterface::readSecretKeys(ids);
 
 	for (int i = 0; i < publiclist.size(); ++i) {
 		KgpgCore::KgpgKey key = publiclist.at(i);
